# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
Jul 17 2013 | F064109 [PDF] [DOC] | Bank of America v. Roberts 7/17/13 CA5 Case Details
Jul 15 2013 | F064045 [PDF] [DOC] | POET v. Air Resources Bd. 7/15/13 CA5 Case Details
Jul 08 2013 | F065690 [PDF] [DOC] | Citzens for Ceres v. Super. Ct. 7/8/13 CA5 Case Details
Jul 01 2013 | F059511N [PDF] [DOC] | In re Cabrera 7/1/13 CA5 Case Details
Jun 13 2013 | F057722N [PDF] [DOC] | P. v. Pizarro 6/13/13 CA5 Case Details
Jun 11 2013 | F059511A [PDF] [DOC] | In re Cabrera 6/11/13 CA5 Case Details
May 31 2013 | F064930 [PDF] [DOC] | San Joaquin Raptor Rescue Center v. Co. of Merced 5/31/13 CA5 Case Details
May 30 2013 | F065067 [PDF] [DOC] | Estate of Bonzi 5/30/13 CA5 Case Details
May 23 2013 | F057722A [PDF] [DOC] | P. v. Pizarro 5/21/13 CA5 Case Details
May 15 2013 | F064590 [PDF] [DOC] | Castleman v. Sagaser 4/15/13 CA5 Case Details
May 02 2013 | F062474M [PDF] [DOC] | P. v. Xiong 5/2/13 CA5 Case Details
Apr 30 2013 | F062474 [PDF] [DOC] | P. v. Xiong 4/30/13 CA5 Case Details
Apr 29 2013 | F063555 [PDF] [DOC] | Cty. of Tulare v. Nunes 4/29/13 CA5 Case Details
Apr 29 2013 | F064841 [PDF] [DOC] | In re Robert M. 4/29/13 CA5 Case Details
Apr 26 2013 | F063887M [PDF] [DOC] | Perry v. Co. of Fresno 4/26/13 CA5 Case Details
Apr 04 2013 | F063887 [PDF] [DOC] | Perry v. Fresno Cty. 4/3/13 CA5 Case Details
Mar 27 2013 | F064240 [PDF] [DOC] | McDaniel v. Asuncion 3/27/13 CA5 Case Details